def delegate_job_action(
    goal: str, role: str, in_files: list, out_files: list, **kwargs
) -> str:
    """Delegate a job and return its content."""
    return "Rejected, this action is not implemented."
